

import sys

from exasol.ai.mcp.server.db_connection import DbConnection
from loguru import logger
from typing_extensions import TypedDict

from exasol_mcp_server_governed_sql.helpers import get_environment

env = get_environment()

#######################################################
## Working status of Text2SQL transformation process ##
#######################################################

class GraphState(TypedDict):
    question: str                 # The natural language question
    connection: DbConnection      # The database connection with Impersonation
    db_schema: str                # The database schema to be used
    sql_statement: str            # The generated SQL statement
    query_num_rows: int           # The number of rows returned
    query_result: str             # The result of the generated SQL statement
    display_result: str           # The transformed result into a visual version
    num_of_attempts: int          # The number of attempts to generate a valid SQL statement
    is_allowed: str               # Is the generated SQL statement allowed (READ-ONLY, currently)
    is_relevant: str              # Does the natural language fit to the underlying database schema
    sql_is_valid: str             # SQL statements accepted by the Exasol database
    sql_error: str                # The SQL error returned by the Exasol database, if any
    info: str                     # Additional INFO field


########################
## Set-Up Logging     ##
########################

LOGGING = env['logger']
LOGGING_MODE = env['logger_mode']

logger.add(sys.stdout, colorize=True, format="<green>{time}</green> <level>{message}</level>", filter="my_module", level="INFO")
logger.add(env['logger_destination'])


from typing import Optional


class Filter:
    def inlet(self, body: dict, user: Optional[dict] = None) -> dict:
        email_id = user.get("email")

        context_message = {
            "role": "system",
            "content": f"logged_in_user_email_id is {email_id}",
        }
        body.setdefault("messages", []).insert(0, context_message)

        return body





from pydantic import BaseModel, Field

from exasol_mcp_server_governed_sql.intro import env, GraphState,logger, LOGGING
from exasol_mcp_server_governed_sql.helpers import set_logging_label
from exasol_mcp_server_governed_sql.llm import invoke_llm

###############################################################################################
## Inform user that query seems to be not relevant / does not fit to desired database schema ##
###############################################################################################

class BadRelevanceAnswer(BaseModel):
    info_about_relevance: str = Field(
        description="Informing the user about question and database schema mismatch"
    )

def t2s_info_query_not_relevant(state: GraphState):

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_info_query_not_relevant -----")

    system_prompt = "You are a educative assistant who responds in a strict manner!"
    info_message = "The human question and the database schema do not fit together!"

    result = invoke_llm(base=env["llm_server_url"],
                        api=env["llm_server_api_token"],
                        model=env["llm_server_model_check"],
                        temperature=env['temperature_info'],
                        prompt=system_prompt,
                        query=info_message,
                        output=BadRelevanceAnswer)

    state["info"] = result.info_about_relevance

    return state


##############################################################################
## Inform user that (currently) on 'SELECT' (READ-ONLY) queries are allowed ##
##############################################################################

class SQLTypeNotAllowed(BaseModel):
    info_about_bad_sql_type: str = Field(
        description="Informing the user that the type of the SQL statement is not allowed."
    )

def t2s_info_unable_query_type(state: GraphState):

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_info_unable_query_type -----")

    system_prompt = "You are a educative assistant who responds in a strict manner"
    info_message = "Explain: The SQL query type is not allowed."

    result = invoke_llm(base=env["llm_server_url"],
                        api=env["llm_server_api_token"],
                        model=env["llm_server_model_check"],
                        temperature=env['temperature_info'],
                        prompt=system_prompt,
                        query=info_message,
                        output=SQLTypeNotAllowed)

    state["info"] = result.info_about_bad_sql_type

    return state

##############################################################################################
## Inform user that the text-to-sql tool cannot create a valid SQL statement in 3 attempts. ##
##############################################################################################

class UnableCreateSQL(BaseModel):
    info_unable_create_sql: str = Field(
        description="Informing the user that the text-to-sql tool cannot create a valid SQL statement"
    )

def t2s_info_unable_create_sql(state: GraphState):

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_info_unable_create_sql -----")

    system_prompt = "You are a educative assistant who responds in a strict manner."
    info_message = "Text-to-SQL tool cannot create a valid SQL statement, explain the SQL dialect does not work."

    result = invoke_llm(base=env["llm_server_url"],
                        api=env["llm_server_api_token"],
                        model=env["llm_server_model_check"],
                        temperature=env['temperature_info'],
                        prompt=system_prompt,
                        query=info_message,
                        output=UnableCreateSQL)

    state["info"] = result.info_unable_create_sql

    return state



##############################################################
## Exasol MCP server with Text-to-SQL query option          ##
## Module: SQL AUDIT / SEARCH                               ##
##----------------------------------------------------------##
## Version 1.0.0 DirkB@Exasol : Initial version             ##
##############################################################

import chromadb
import datetime
import sys

from pydantic import BaseModel, Field

from exasol_mcp_server_governed_sql.helpers import get_environment


##
## Add-On: Retrieve the past SQL Statements stored by the user for reference.
##

class SqlHistory(BaseModel):
    sql_history: str = Field(
        description="The SQL history set converted into a nice and shiny table in MARKDOWN syntax."
    )


def text_to_sql_audit(search_text: str, db_schema: str, number_results: int) -> list:

    env = get_environment()
    print(env['vectordb_persistent_storage'])
    result = []
    try:

        search_text = "*" # f"*{search_text}*"
        vectordb_client = chromadb.PersistentClient(path=env['vectordb_persistent_storage'])
        collection = vectordb_client.get_collection(name='SQL_Audit')
        result = collection.query(query_texts=[search_text],
                               n_results=number_results,
                               where= {'db_schema': db_schema },

                               include=["documents", "metadatas"])

    except Exception as e:
        print(f"ChromaDB - Error: {e}", file=sys.stderr)

    ## ChromaDB cannot sort like 'ORDER BY'

    print(result)

    combined = list(zip(
        result['ids'][0],
        result['documents'][0],
        result['metadatas'][0],
    ))
    sorted_combined = sorted(combined, key=lambda x: datetime.datetime.fromisoformat(x[2]['execution_date']), reverse=True)

    result['ids'][0], result['documents'][0], result['metadatas'][0] = map(list, zip(*sorted_combined))

    return sorted_combined


###############################
## A mix of helper functions ##
###############################

import loguru
import os
import time


from dotenv import load_dotenv, find_dotenv


###############################
## Build env from .env file  ##
###############################


def get_environment() -> dict:

    load_dotenv()

    env = {
            "dsn": os.getenv("EXA_DSN"),
            "db_user": os.getenv("EXA_USER"),
            "db_password": os.getenv("EXA_PASSWORD"),
            "llm_server_url": os.getenv("EXA_MCP_LLM_SERVER_URL"),
            "llm_server_api_token": os.getenv("EXA_MCP_LLM_SERVER_API_KEY"),
            "llm_server_model_check": os.getenv("EXA_MCP_LLM_TRANSFORMATION"),
            "llm_server_sql_transform": os.getenv("EXA_MCP_LLM_TRANSFORMATION"),
            "llm_server_result_rendering": os.getenv("EXA_MCP_LLM_RENDERING"),
            "vectordb_persistent_storage": os.getenv("EXA_MCP_VECTORDB_FILE"),
            "vectordb_similarity_distance": os.getenv("EXA_MCP_VECTORDB_SIMILARITY_DISTANCE"),
            "logger": os.getenv("EXA_MCP_LOGGER"),
            "logger_mode": os.getenv("EXA_MCP_LOGGER_MODE").lower(),
            "logger_destination": os.getenv("EXA_MCP_LOGGER_FILE"),
            "temperature_relevance_check": os.getenv("EXA_MCP_LLM_TEMPERATURE_RELEVANCE"),
            "temperature_translation": os.getenv("EXA_MCP_LLM_TEMPERATURE_TRANSLATION"),
            "temperature_query_rewrite": os.getenv("EXA_MCP_LLM_TEMPERATURE_QUERY_REWRITE"),
            "temperature_rendering": os.getenv("EXA_MCP_LLM_TEMPERATURE_RENDERING"),
            "temperature_info": os.getenv("EXA_MCP_LLM_TEMPERATURE_INFO"),
        }

    print(env)

    return env


##############################################
## A tiny helper for printing elapsed times ##
##############################################

def elapsed_time(logging: bool, logger: loguru.logger, start_time, label) -> None:

    if logging:
        et = time.time() - start_time
        logger.info(f"{label}: {et:.2f} seconds")


#################################
## A tiny Helper to set labels ##
#################################

def set_logging_label(logging: bool, logger: loguru.logger, label: str) -> None:

    if logging:
        logger.info(label)



##############################################################
## Exasol MCP server with Text-to-SQL query option          ##
## Module: Text to SQL translation                          ##
##----------------------------------------------------------##
## Version 1.0.0 DirkB@Exasol : Initial version             ##
##############################################################

import chromadb
import re
import time

from datetime import datetime
from langgraph.graph import StateGraph, START, END
from pydantic import BaseModel, Field
from pyexasol import ExaConnection, ExaError
from sql_formatter.core import format_sql

## Project packages

from exasol.ai.mcp.server.server_settings import ExaDbResult
from exasol_mcp_server_governed_sql.intro import (
    env,
    GraphState,
    logger,
    LOGGING,
    LOGGING_MODE
)
from exasol_mcp_server_governed_sql.helpers import elapsed_time
from exasol_mcp_server_governed_sql.llm import invoke_llm
from exasol_mcp_server_governed_sql.helpers import set_logging_label
from exasol_mcp_server_governed_sql.database_functions import t2s_database_schema
from exasol_mcp_server_governed_sql.database_functions import get_sql_query_type
from exasol_mcp_server_governed_sql.load_prompts import load_translation_prompt
from exasol_mcp_server_governed_sql.load_prompts import load_render_prompt
from exasol_mcp_server_governed_sql.info_messages_llm import (
    t2s_info_query_not_relevant,
    t2s_info_unable_query_type,
    t2s_info_unable_create_sql
)
from exasol_mcp_server_governed_sql.routing import (
    t2s_check_sql_router,
    t2s_relevance_router,
    t2s_sql_valid_router,
    t2s_max_tries_router
)

exa_connection: ExaConnection = None


##################################################################
## Check if human question relates to requested database schema ##
##################################################################

class CheckIsRelevant(BaseModel):
    is_relevant: str = Field(
        description="Checks, if the question is related to the database schema. 'YES' or 'NO'."
    )

def t2s_check_relevance(state: GraphState) -> str:

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_check_relevance -----")
    start_time_relevance_test = time.time()

    schema = t2s_database_schema(connection=state['connection'], db_schema=state['db_schema'])

    system_prompt = f"""
    You are an assistant that checks if the given human question: 
    
    {state['question']}
    
    relates to the following database schema
    
    {schema}
    
    Answer with "YES" if question relates to the given schema, otherwise answer with "NO", only!
    """
    start_time_relevance_test = time.time()
    result = invoke_llm(base=env["llm_server_url"],
                                      api=env["llm_server_api_token"],
                                      model=env["llm_server_model_check"],
                                      temperature=env['temperature_relevance_check'],
                                      prompt=system_prompt,
                                      query=state['question'],
                                      output=CheckIsRelevant)
    elapsed_time(logging=LOGGING, logger=logger, start_time=start_time_relevance_test, label="Time needed for Relevance test")

    state['is_relevant'] = result.is_relevant

    if LOGGING == 'True' and LOGGING_MODE == 'debug':
        logger.debug(f"RESULT: {result.is_relevant}")

    return state


#############################################################################
## The core step to transform human language formulated questions into SQL ##
#############################################################################

class TransformIntoSql(BaseModel):
    sql_query: str = Field(
        description="The SQL query corresponding to the user's natural language question."
    )

def t2s_human_language_to_sql(state: GraphState):

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_human_language_to_sql -----")

    state['num_of_attempts'] +=  1

    db_schema = state['db_schema']

    schema = t2s_database_schema(state['connection'], db_schema)

    system_prompt = load_translation_prompt(db_schema=db_schema, schema=schema)
    system_prompt_length = len(system_prompt)

    ##
    ## Check VectorDB for a similar question and SQL Statement,
    ## retrieve a threshold for similarity from the .env file
    ##

    try:
        vectordb_client = chromadb.PersistentClient(path=env['vectordb_persistent_storage'])
        sql_collection = vectordb_client.get_or_create_collection(name="SQL_Audit")
        tmp = sql_collection.query(query_texts=state['question'], n_results=1, include=["distances", "documents", "metadatas"])

        if float(tmp["distances"][0][0]) <= float(env['vectordb_similarity_distance']):
            system_prompt += f"""
                                For a similar natural language question you have created the following SQL statement:
                                
                                {tmp['metadatas'][0][0]['sql']}
                                
                            """
    except Exception as e:
        logger.error(f"ChromaDB - Error: {e}")

    if LOGGING == 'True' and LOGGING_MODE == 'debug':
        logger.debug(f"System-Prompt for translation: {system_prompt}")

    start_time_llm = time.time()
    result = invoke_llm(base=env["llm_server_url"],
                        api=env["llm_server_api_token"],
                        model=env["llm_server_model_check"],
                        temperature=env['temperature_translation'],
                        prompt=system_prompt,
                        query=state['question'],
                        output=TransformIntoSql)



    elapsed_time(logging=LOGGING, logger=logger, start_time=start_time_llm, label=f"Time needed for SQL Creation (Prompt-Length: {system_prompt_length})")

    state["sql_statement"] = result.sql_query

    if LOGGING == 'True' and LOGGING_MODE == 'debug':
        sql_for_logger = format_sql(result.sql_query)
        logger.debug(f"SQL created: \n \n {sql_for_logger} \n\n")



    return  state


########################################################
## Check, if we allow the SQL statement for execution ##
########################################################

def t2s_check_sql_is_allowed(state: GraphState):

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_check_sql_is_allowed -----")

    if get_sql_query_type(state["sql_statement"]):
        state['is_allowed'] = "YES"
    else:
        state['is_allowed'] = "NO"

    return state


#######################
## Execute the query ##
#######################

def t2s_execute_query(state: GraphState):

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_execute_query -----")
    connection = state['connection']

    try:

        start_time_exa_query = time.time()

        statement = connection.execute_query(state['sql_statement'])
        rows = statement.fetchall()

        elapsed_time(logging=LOGGING, logger=logger, start_time=start_time_exa_query, label="Elapsed Time on Exasol-DB - Execute Query")

        col_names = statement.column_names()
        rows.insert(0, col_names)

        state['query_result'] = str(ExaDbResult(rows))
        state['query_num_rows'] = statement.rowcount()

    except ExaError as e:
        state['sql_is_valid'] = "NO"
        state['sql_error'] = str(e)
        logger.error(f"SQL Execution Error: {e}")
    else:
        state['sql_is_valid'] = "YES"
        state['sql_error'] = "None"

        ## Store the generated SQL statement and the natural language question into a VectorDB
        ## We will use it for similarity search and may add this query to the prompt for future
        ## natural language questions

        if rows is not None:
            if LOGGING == 'True' and LOGGING_MODE == 'debug':
                logger.debug("STEP: Storing or updating SQL statement in Vector-DB.")

            vectordb_client = chromadb.PersistentClient(path=env['vectordb_persistent_storage'])
            sql_collection = vectordb_client.get_or_create_collection(name="SQL_Audit")

            ## Check, if query exists in VectorDB

            start_time_chroma = time.time()

            tmp = sql_collection.query(query_texts=state['question'], n_results=1,
                                       include=["distances", "documents", "metadatas"],
                                       where={"$and": [{'user': env['db_user'].lower()},
                                                       {'db_schema': state['db_schema']},
                                                       ]
                                              },
                                       )

            ## VectorDB is empty, no distances stored:

            if not tmp["distances"][0]:
                new_idx = sql_collection.count() + 1
                sql_collection.add(
                    documents=[state['question']],
                    metadatas=[{"sql": state['sql_statement'],
                                "execution_date": str(datetime.now()),
                                "db_schema": state['db_schema'],
                                "user": env['db_user'].lower(),
                                "origin": "text-to-sql"}],
                    ids=[f"{new_idx}"]
                )
                if LOGGING == 'True' and LOGGING_MODE == 'debug':
                    logger.debug("STEP: Vector-DB-SQL initially written")

            elif float(tmp["distances"][0][0]) > 0.0001:

                    new_idx = sql_collection.count() + 1
                    sql_collection.add(
                        documents=[state['question']],
                        metadatas=[{"sql": state['sql_statement'],
                                    "execution_date": str(datetime.now()),
                                    "db_schema": state['db_schema'],
                                    "user": env['db_user'].lower(),
                                    "origin": "text-to-sql"}],
                        ids=[f"{new_idx}"]
                    )
                    if LOGGING == 'True' and LOGGING_MODE == 'debug':
                        logger.debug("STEP: Vector-DB-SQL written")
            else:
                sql_collection.update(
                    ids=[ tmp['ids'][0][0] ],
                    metadatas=[ {"execution_date": str(datetime.now())} ]
                )
                if LOGGING == 'True' and LOGGING_MODE == 'debug':
                    logger.debug("STEP: Vector-DB-SQL initially updated")

            elapsed_time(logging=LOGGING, logger=logger, start_time=start_time_chroma, label="Elapsed Time on VectorDB")

    return state


##########################################################################
## Check, if the SQL statement execution was correct or raised an error ##
##########################################################################

def t2s_check_sql_valid(state: GraphState):

    if state['sql_error'] == "None":
        state['sql_is_valid'] = "YES"
    else:
        state['sql_is_valid'] = "NO"

    return state


##################################################
## Post-Processing of the SQL execution process ##
##################################################

class DisplayResult(BaseModel):
    display_result: str = Field(
        description="The result set converted into a nice and shiny table in MARKDOWN syntax."
    )

def t2s_show_answer(state: GraphState):

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_show_answer -----")


    result = re.search(r"(\[.*\])", state['query_result'])
    result_set = result.group(0)

    system_prompt = load_render_prompt(db_schema=state['db_schema'])
    system_prompt_length = len(system_prompt)

    question = f"""Transform the dataset below into a table in markdown syntax. For a result
    with one value only, build a table with one column:
    
    {result_set}
    """

    if LOGGING == 'True' and LOGGING_MODE == 'debug':
        logger.debug(f"System-Prompt: \n \n {system_prompt} \n\n")
        logger.debug(f"Question:: \n \n {question} \n\n")

    start_time_render = time.time()
    result = invoke_llm(base=env["llm_server_url"],
                        api=env["llm_server_api_token"],
                        model=env["llm_server_model_check"],
                        temperature=env['temperature_rendering'],
                        prompt=system_prompt,
                        query=state['question'],
                        output=DisplayResult)

    state["display_result"] = str(result.display_result)

    elapsed_time(logging=LOGGING, logger=logger, start_time=start_time_render, label=f"Time needed for rendering answer (Prompt-Length: {system_prompt_length})")

    return state


#########################################################
## Rewriting the question to try a new SQL translation ##
#########################################################

class NewVariantOfQuestion(BaseModel):
    new_question: str = Field(
        description="Reformulated Question to gain a valid SQL transformation."
    )
def t2s_correct_query(state: GraphState):

    set_logging_label(logging=LOGGING, logger=logger, label="----- t2s_correct_query -----")

    ## Reformulate the question to initiate a new SQL translation

    system_prompt = "You are a correcting assistant and re-write the question, but keep the semantics."
    info_message = f"Rewrite the following question: {state['question']} "

    start_time_rewrite = time.time()
    result = invoke_llm(base=env["llm_server_url"],
                        api=env["llm_server_api_token"],
                        model=env["llm_server_model_check"],
                        temperature=env['temperature_query_rewrite'],
                        prompt=system_prompt,
                        query=info_message,
                        output=NewVariantOfQuestion)
    elapsed_time(logging=LOGGING, logger=logger, start_time=start_time_rewrite, label="Time needed for rewriting question")
    state["question"] = result.new_question

    return state





def t2s_check_max_tries(state: GraphState) -> str:
    return state

def t2s_sql_execution_router(state: GraphState):
    return state

############################################################################
## The Process Flow to create transformation of natural language into SQL ##
############################################################################

async def t2s_start_process(state: GraphState):

    ## Create a connection to the Exasol database ##

    total_start_time = time.time()

    set_logging_label(logging=LOGGING, logger=logger, label="########## Begin of Translation Process ##########")

    state['is_allowed'] = "NO"
    state['sql_is_valid'] = "NO"
    state['num_of_attempts'] = 0
    state['display_result'] = ""

    workflow = StateGraph(GraphState)

    workflow.add_edge(START, "check_relevance")
    workflow.add_node("check_relevance", t2s_check_relevance)
    workflow.add_node("transform_into_sql", t2s_human_language_to_sql)
    workflow.add_node("info_unable_query_type", t2s_info_unable_query_type)
    workflow.add_node("check_sql_is_allowed", t2s_check_sql_is_allowed)
    workflow.add_node("execute_query", t2s_execute_query)
    workflow.add_node("show_answer", t2s_show_answer)
    workflow.add_node("info_query_not_relevant", t2s_info_query_not_relevant)
    workflow.add_node("correct_query", t2s_correct_query)
    workflow.add_node("check_max_tries", t2s_check_max_tries)
    workflow.add_node("info_unable_create_sql", t2s_info_unable_create_sql)
    workflow.add_node("check_sql_valid", t2s_check_sql_valid)

    workflow.add_conditional_edges(
        "check_relevance",
        t2s_relevance_router,
        {
            "YES": "transform_into_sql",
            "NO": "info_query_not_relevant",
        },
    )

    workflow.add_conditional_edges(
        "check_max_tries",
        t2s_max_tries_router,
        {
            "NO": "correct_query",
            "YES": "info_unable_create_sql"
        }

    )

    workflow.add_edge("transform_into_sql", "check_sql_is_allowed")

    workflow.add_conditional_edges(
        "check_sql_is_allowed",
        t2s_check_sql_router,
        {
            "YES": "execute_query",
            "NO": "info_unable_query_type",
        }
    )

    workflow.add_edge("execute_query", "check_sql_valid")

    workflow.add_conditional_edges(
        "check_sql_valid",
        t2s_sql_valid_router,
        {
            "YES": "show_answer",
            "NO": "check_max_tries"
        }
    )

    workflow.add_edge("show_answer", END)
    workflow.add_edge("correct_query", "transform_into_sql")
    workflow.add_edge("info_query_not_relevant", END)
    workflow.add_edge("info_unable_create_sql", END)

    t2s_process = workflow.compile()

    state = await t2s_process.ainvoke(state)

    set_logging_label(logging=LOGGING, logger=logger, label="\n")
    elapsed_time(logging=LOGGING, logger=logger, start_time=total_start_time, label="Total Time")
    set_logging_label(logging=LOGGING, logger=logger, label="########## End of Translation Process #########\n\n\n")

    return state







import chromadb
import time

from datetime import datetime

from exasol_mcp_server_governed_sql.intro import (
    env,
    logger,
    LOGGING,
    LOGGING_MODE
)

from exasol_mcp_server_governed_sql.helpers import elapsed_time


def learn_sql(question: str, sql_statement: str, db_schema: str) -> list:

    #env = get_environment()

    if LOGGING == 'True' and LOGGING_MODE == 'debug':
        logger.debug("STEP: Storing pre-define combination of Question and SQL into VectorDB.")

    vectordb_client = chromadb.PersistentClient(path=env['vectordb_persistent_storage'])
    sql_collection = vectordb_client.get_or_create_collection(name="Questions_SQL_History")

    ## Check, if query exists in VectorDB

    start_time_chroma = time.time()

    new_idx = sql_collection.count() + 1
    sql_collection.add(
        documents=[ question ],
        metadatas=[{"sql": sql_statement,
                    "execution_date": str(datetime.now()),
                    "db_schema": db_schema,
                    "user": 'system',
                    "origin": "learn_sql"}],
        ids=[f"{new_idx}"]
    )
    if LOGGING == 'True' and LOGGING_MODE == 'debug':
        logger.debug("STEP: Vector-DB-SQL[Learn SQL] with Question/SQL written")


    elapsed_time(logging=LOGGING, logger=logger, start_time=start_time_chroma, label="Elapsed Time on VectorDB")

    return [ "Question / SQ Statement combination stored!" ]




#################################################################################
## Load the important prompts for translation and rendering from external file ##
##-----------------------------------------------------------------------------##
## You can modify the prompt to your needs with touching the code              ##
#################################################################################

import importlib.resources

def load_translation_prompt(db_schema: str, schema: str) -> str:

    """ Load the Exasol prompt for text to sql transformation."""

    prompt = importlib.resources.read_text("exasol_mcp_server_governed_sql.resources", "sql_translation_prompt.txt")

    return prompt.format(db_schema=db_schema, schema=schema)


def load_render_prompt(db_schema: str) -> str:
    """ Load the Exasol prompt for text to sql transformation."""

    prompt = importlib.resources.read_text("exasol_mcp_server_governed_sql.resources", "result_rendering_prompt.txt")

    return prompt.format(db_schema=db_schema)